collective geo's documentation
==============================

.. toctree::
   :maxdepth: 3

   installation.rst
   howto.rst

   corepackages.rst
   otherpackages.rst


.. include:: ../OVERVIEW.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
